@@ -11,8 +11,8 @@ impl Robot for BatteryBot {
     }
 
     fn opcontrol(&'static self, _ctx: Context) {
-        println!("Battery Capacity: {}", Battery::get_current().unwrap());
-        println!("Battery Current: {}", Battery::get_capacity().unwrap());
+        println!("Battery Capacity: {}", Battery::get_capacity().unwrap());
+        println!("Battery Current: {}", Battery::get_current().unwrap());
         println!(
             "Battery Temperature: {}",
             Battery::get_temperature().unwrap()
