@@ -8,7 +8,7 @@
  * This file should not be modified by users, since it gets replaced whenever
  * a kernel upgrade occurs.
  *
- * Copyright (c) 2017-2021, Purdue University ACM SIGBots.
+ * Copyright (c) 2017-2022, Purdue University ACM SIGBots.
  * All rights reserved.
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
@@ -40,9 +40,9 @@
 #endif /* __cplusplus */
 
 #define PROS_VERSION_MAJOR 3
-#define PROS_VERSION_MINOR 5
-#define PROS_VERSION_PATCH 2
-#define PROS_VERSION_STRING "3.5.2"
+#define PROS_VERSION_MINOR 6
+#define PROS_VERSION_PATCH 0
+#define PROS_VERSION_STRING "3.6.0"
 
 #define PROS_ERR (INT32_MAX)
 #define PROS_ERR_F (INFINITY)
@@ -53,6 +53,7 @@
 #include "pros/ext_adi.h"
 #include "pros/gps.h"
 #include "pros/imu.h"
+#include "pros/link.h"
 #include "pros/llemu.h"
 #include "pros/misc.h"
 #include "pros/motors.h"
@@ -75,6 +76,7 @@
 #include "pros/rtos.hpp"
 #include "pros/screen.hpp"
 #include "pros/vision.hpp"
+#include "pros/link.hpp"
 #endif
 
 #endif  // _PROS_API_H_
