@@ -8,7 +8,7 @@
  * This file should not be modified by users, since it gets replaced whenever
  * a kernel upgrade occurs.
  *
- * Copyright (c) 2017-2021, Purdue University ACM SIGBots.
+ * Copyright (c) 2017-2022, Purdue University ACM SIGBots.
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -630,6 +630,50 @@ int32_t ext_adi_gyro_reset(ext_adi_gyro_t gyro);
  */
 int32_t ext_adi_gyro_shutdown(ext_adi_gyro_t gyro);
 
+/**
+ * Reference type for an initialized potentiometer.
+ *
+ * This merely contains the port number for the potentiometer, unlike its use as an
+ * object to store gyro data in PROS 2.
+ */
+typedef int32_t ext_adi_potentiometer_t;
+
+/**
+ * Initializes a potentiometer on the given port. 
+ *
+ * This function uses the following values of errno when an error state is
+ * reached:
+ * ENXIO - The given value is not within the range of ADI Ports
+ * EADDRINUSE - The port is not configured as a potentiometer
+ *
+ * \param port
+ *        The ADI port to initialize as a gyro (from 1-8, 'a'-'h', 'A'-'H')
+ * \param potentiometer_type
+ *        An adi_potentiometer_type_e_t enum value specifying the potentiometer version type
+ *
+ * \return An adi_potentiometer_t object containing the given port, or PROS_ERR if the
+ * initialization failed.
+ */
+ext_adi_potentiometer_t ext_adi_potentiometer_init(uint8_t smart_port, uint8_t adi_port, adi_potentiometer_type_e_t potentiometer_type); 
+
+/**
+ * Gets the current potentiometer angle in tenths of a degree.
+ *
+ * The original potentiometer rotates 250 degrees thus returning an angle between 0-250 degrees.
+ * Potentiometer V2 rotates 333 degrees thus returning an angle between 0-333 degrees.
+ *
+ * This function uses the following values of errno when an error state is
+ * reached:
+ * ENXIO - The given value is not within the range of ADI Ports
+ * EADDRINUSE - The port is not configured as a potentiometer
+ *
+ * \param potentiometer
+ *        The adi_potentiometer_t object for which the angle will be returned
+ *
+ * \return The potentiometer angle in degrees.
+ */
+double ext_adi_potentiometer_get_angle(ext_adi_potentiometer_t potentiometer);
+
 #ifdef __cplusplus
 }  // namespace c
 }  // namespace pros
